@@ -13,6 +13,7 @@ from sklearn.isotonic import IsotonicRegression
 
 from skgstat import estimators, models, binning
 from skgstat import plotting
+from skgstat.util import shannon_entropy
 
 
 class Variogram(object):
@@ -433,10 +434,13 @@ class Variogram(object):
 
         .. versionchanged:: 0.3.8
             added 'fd', 'sturges', 'scott', 'sqrt', 'doane'
-        
+
         .. versionchanged:: 0.3.9
             added 'kmeans', 'ward'
 
+        .. versionchanged:: 0.4.0
+            added 'stable_entropy'
+
         Parameters
         ----------
         bin_func : str
@@ -451,6 +455,7 @@ class Variogram(object):
                 * 'doane'
                 * 'kmeans'
                 * 'ward'
+                * 'stable_entropy'
 
         Returns
         -------
@@ -505,6 +510,15 @@ class Variogram(object):
         merge pairs of clusters until there are only `n` remaining clusters.
         The merging is done by minimizing the variance for the merged cluster.
 
+        **`'stable_entropy'`** will adjust `n` bin edges by minimizing the
+        absolute differences between each lag's Shannon Entropy. This will
+        lead to uneven bin widths. Each lag class value distribution will be
+        of comparable intrinsic uncertainty from an information theoretic
+        point of view, which makes the semi-variances quite comparable.
+        However, it is not guaranteed, that the binning makes any sense
+        from a geostatistical point of view, as the first lags might be way
+        too wide.
+
         See Also
         --------
         Variogram.bin_func
@@ -532,15 +546,25 @@ class Variogram(object):
         # switch the input
         if bin_func.lower() == 'even':
             self._bin_func = binning.even_width_lags
+
         elif bin_func.lower() == 'uniform':
             self._bin_func = binning.uniform_count_lags
+
         elif bin_func.lower() == 'kmeans':
             # define a helper to pass kwargs
             def wrapper(distance, n, maxlag):
                 return binning.kmeans(distance, n, maxlag, **self._kwargs)
             self._bin_func = wrapper
+
         elif bin_func.lower() == 'ward':
             self._bin_func = binning.ward
+
+        elif bin_func.lower() == 'stable_entropy':
+            # define a wrapper
+            def wrapper(distances, n, maxlag):
+                return binning.stable_entropy_lags(distances, n, maxlag, **self._kwargs)
+            self._bin_func = wrapper
+
         elif isinstance(bin_func, str):
             # define a helper wrapper
             def wrapper(distances, n, maxlag):
@@ -548,9 +572,11 @@ class Variogram(object):
 
             self._bin_func = wrapper
             self._n_lags = None
+
         elif callable(bin_func):
             self._bin_func = bin_func
             bin_func = 'custom'
+
         else:
             raise AttributeError('bin_func has to be of type string.')
 
@@ -869,8 +895,11 @@ class Variogram(object):
         cost function, which divides the residuals by their uncertainty.
 
         When setting fit_sigma, the array of uncertainties itself can be
-        given, or one of the strings: ['linear', 'exp', 'sqrt', 'sq']. The
-        parameters described below refer to the setter of this property.
+        given, or one of the strings: ['linear', 'exp', 'sqrt', 'sq', 'entropy']. 
+        The parameters described below refer to the setter of this property.
+
+        .. versionchanged:: 0.3.11
+            added the 'entropy' option.
 
         Parameters
         ----------
@@ -889,6 +918,8 @@ class Variogram(object):
                 :math:`w = \sqrt(w_n)`
               * **sigma='sq'**: The residuals get weighted by the function:
                 :math:`w = w_n^2`
+              * **sigma='entropy'**: Calculates the Shannon Entropy as 
+                intrinsic uncertainty of each lag class.
 
         Returns
         -------
@@ -937,9 +968,24 @@ class Variogram(object):
         # squared function of distance
         elif self._fit_sigma == 'sq':
             return (self.bins / np.max(self.bins)) ** 2
+
+        # entropy
+        elif self._fit_sigma == 'entropy':
+            # get the binning using scotts rule
+            bins = np.histogram_bin_edges(self.distance, 'scott')
+
+            # get the maximum entropy
+#            hmax = np.log2(len(self.distance))
+
+            # apply the entropy
+            h = np.asarray([shannon_entropy(grp, bins) for grp in self.lag_classes() if len(grp) > 0])
+            return 1. / h
+
         else:
-            raise ValueError("fit_sigma is not understood. It has to be an " +
-                             "array or one of ['linear', 'exp', 'sqrt', 'sq'].")
+            raise ValueError(
+                "fit_sigma is not understood. It has to be an " +
+                "array or one of ['linear', 'exp', 'sqrt', 'sq', 'entropy']."
+            )
 
     @fit_sigma.setter
     def fit_sigma(self, sigma):
