@@ -129,6 +129,40 @@ class TestVariogramArguments(unittest.TestCase):
             decimal=1
         )
 
+    def test_binning_method_stable(self):
+        V = Variogram(self.c, self.v, bin_func='stable_entropy')
+
+        assert_array_almost_equal(
+            V.bins,
+            np.array([4.3, 8.4, 12.8, 17.1, 21.4, 25.2, 29.9, 33.2, 38.5, 42.8]),
+            decimal=1
+        )
+
+    def test_binning_method_stable_maxiter(self):
+        # increase maxiter - the result should stay the same
+        V = Variogram(self.c, self.v, bin_func='stable_entropy', binning_maxiter=20000)
+
+        assert_array_almost_equal(
+            V.bins,
+            np.array([4.3, 8.4, 12.8, 17.1, 21.4, 25.2, 29.9, 33.2, 38.5, 42.8]),
+            decimal=1
+        )
+
+    def test_binning_method_stable_fix_bins(self):
+        # use 50 bins over the sqrt method - this should change the bins
+        V = Variogram(
+            self.c,
+            self.v,
+            bin_func='stable_entropy',
+            binning_entropy_bins=50
+        )
+
+        assert_array_almost_equal(
+            V.bins,
+            np.array([4.2, 8.6, 12.8, 17.1, 21.2, 25.5, 29.3, 33.2, 37.4, 43.]),
+            decimal=1
+        )
+
     def test_binning_change_nlags(self):
         V = Variogram(self.c, self.v, n_lags=5)
 
@@ -432,10 +466,9 @@ class TestVariogramFittingProcedure(unittest.TestCase):
 
         with self.assertRaises(ValueError) as e:
             self.V.fit_sigma
-            
-        self.assertEqual(
-            str(e.exception),
-            "fit_sigma is not understood. It has to be an array or one of ['linear', 'exp', 'sqrt', 'sq']."
+
+        self.assertTrue(
+            "fit_sigma is not understood." in str(e.exception)
         )
 
     def test_fit_sigma_linear(self):
@@ -490,7 +523,22 @@ class TestVariogramFittingProcedure(unittest.TestCase):
         assert_array_almost_equal(
             self.V.parameters, [5.4, 0.1,  18.5], decimal=1
         )
-    
+
+    def test_fit_sigma_entropy(self):
+        # load data sample
+        data = pd.read_csv(os.path.dirname(__file__) + '/sample.csv')
+        V = Variogram(
+            data[['x', 'y']].values,
+            data.z.values,
+            n_lags=12,
+            fit_method='ml',
+            fit_sigma='entropy'
+        )
+
+        assert_array_almost_equal(
+            V.parameters, [65.9, 1.3, 0], decimal=1
+        )
+
     def test_fit_sigma_on_the_fly(self):
         self.V.fit(sigma='sq')
 
